@@ -18,31 +18,26 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include "commandexec.h"
-#include "src/settings/kdesvnsettings.h"
+#include "settings/kdesvnsettings.h"
 #include "svnfrontend/svnactions.h"
 #include "svnfrontend/dummydisplay.h"
-#include "src/svnqt/targets.h"
-#include "src/svnqt/url.h"
-#include "src/svnqt/dirent.h"
-#include "src/helpers/sub2qt.h"
-#include "src/helpers/ktranslateurl.h"
-#include "src/helpers/sshagent.h"
-#include "src/svnfrontend/fronthelpers/rangeinput_impl.h"
-#include "src/svnfrontend/copymoveview_impl.h"
+#include "svnqt/targets.h"
+#include "svnqt/url.h"
+#include "svnqt/dirent.h"
+#include "helpers/ktranslateurl.h"
+#include "helpers/sshagent.h"
+#include "helpers/windowgeometryhelper.h"
+#include "svnfrontend/fronthelpers/rangeinput_impl.h"
+#include "svnfrontend/copymoveview_impl.h"
+#include "ksvnwidgets/ksvndialog.h"
 
-#include <kapplication.h>
-#include <kglobal.h>
-#include <kdebug.h>
-#include <kmessagebox.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
-// #include <kdialogbase.h>
-#include <KDialog>
-#include <KVBox>
-#include <ktextbrowser.h>
+#include <KMessageBox>
 
-#include <qfile.h>
+#include <QCommandLineParser>
+#include <QDir>
+#include <QTextBrowser>
 #include <QTextStream>
+#include <QUrlQuery>
 
 class pCPart
 {
@@ -51,7 +46,7 @@ public:
     ~pCPart();
 
     QString cmd;
-    QStringList url;
+    QStringList urls;
     bool ask_revision;
     bool rev_set;
     bool outfile_set;
@@ -59,7 +54,8 @@ public:
     bool force;
     int log_limit;
     SvnActions *m_SvnWrapper;
-    KCmdLineArgs *args;
+    QCommandLineParser *parser;
+    QStringList args;
     svn::Revision start, end;
 
     // for output
@@ -67,12 +63,12 @@ public:
     QTextStream Stdout, Stderr;
     DummyDisplay *disp;
     QMap<int, svn::Revision> extraRevisions;
-    QMap<int, QString> baseUrls;
+    QMap<int, QUrl> repoUrls;
 };
 
 pCPart::pCPart()
     : cmd()
-    , url()
+    , urls()
     , ask_revision(false)
     , rev_set(false)
     , outfile_set(false)
@@ -80,7 +76,7 @@ pCPart::pCPart()
     , force(false)
     , log_limit(0)
     , m_SvnWrapper(NULL)
-    , args(NULL)
+    , parser(NULL)
     , start(svn::Revision::UNDEFINED)
     , end(svn::Revision::UNDEFINED)
     , Stdout(stdout)
@@ -101,7 +97,7 @@ CommandExec::CommandExec(QObject *parent)
     , m_lastMessagesLines(0)
 {
     m_pCPart = new pCPart;
-    m_pCPart->args = 0;
+    m_pCPart->parser = 0;
     SshAgent ag;
     ag.querySshAgent();
 
@@ -110,15 +106,17 @@ CommandExec::CommandExec(QObject *parent)
     m_pCPart->m_SvnWrapper->reInitClient();
 }
 
+
 CommandExec::~CommandExec()
 {
     delete m_pCPart;
 }
 
-int CommandExec::exec(KCmdLineArgs *args)
+int CommandExec::exec(const QCommandLineParser *parser)
 {
-    m_pCPart->args = args;
-    if (!m_pCPart->args) {
+    m_pCPart->parser = const_cast<QCommandLineParser*>(parser);
+    m_pCPart->args = parser->positionalArguments();
+    if (m_pCPart->args.isEmpty()) {
         return -1;
     }
     m_lastMessages.clear();
@@ -130,11 +128,11 @@ int CommandExec::exec(KCmdLineArgs *args)
     bool no_revision = false;
     bool check_force = false;
 
-    if (m_pCPart->args->count() >= 2) {
-        m_pCPart->cmd = m_pCPart->args->arg(1);
+    if (m_pCPart->args.count() >= 2) {
+        m_pCPart->cmd = m_pCPart->args.at(1);
         m_pCPart->cmd = m_pCPart->cmd.toLower();
     }
-    QString slotCmd;
+    QByteArray slotCmd;
     if (!QString::compare(m_pCPart->cmd, "log")) {
         slotCmd = SLOT(slotCmd_log());
     } else if (!QString::compare(m_pCPart->cmd, "cat")) {
@@ -215,22 +213,21 @@ int CommandExec::exec(KCmdLineArgs *args)
         check_force = true;
     }
 
-    bool found = connect(this, SIGNAL(executeMe()), this, slotCmd.toAscii());
+    bool found = connect(this, SIGNAL(executeMe()), this, slotCmd.constData());
     if (!found) {
-        slotCmd = i18n("Command \"%1\" not implemented or known", m_pCPart->cmd);
-        KMessageBox::sorry(0, slotCmd, i18n("SVN Error"));
+        KMessageBox::sorry(0,
+                           i18n("Command \"%1\" not implemented or known", m_pCPart->cmd),
+                           i18n("SVN Error"));
         return -1;
     }
 
     QString tmp;
     QString mainProto;
-    QString _baseurl;
-    for (int j = 2; j < m_pCPart->args->count(); ++j) {
-        KUrl tmpurl = helpers::KTranslateUrl::translateSystemUrl(m_pCPart->args->url(j).prettyUrl());
-        const QMap<QString, QString> q = m_pCPart->args->url(j).queryItems();
-        QString v = q.value("rev");
-        tmpurl.setProtocol(svn::Url::transformProtokoll(tmpurl.protocol()));
-        if (tmpurl.protocol().indexOf("ssh") != -1) {
+    for (int j = 2; j < m_pCPart->args.count(); ++j) {
+        QUrl tmpurl = QUrl::fromUserInput(m_pCPart->args.at(j),
+                                          QDir::currentPath());
+        tmpurl.setScheme(svn::Url::transformProtokoll(tmpurl.scheme()));
+        if (tmpurl.scheme().indexOf(QLatin1String("ssh")) != -1) {
             SshAgent ag;
             // this class itself checks if done before
             ag.addSshIdentities();
@@ -238,9 +235,10 @@ int CommandExec::exec(KCmdLineArgs *args)
         m_pCPart->extraRevisions[j - 2] = svn::Revision::HEAD;
 
         if (tmpurl.isLocalFile() && (j == 2 || !dont_check_second) && !dont_check_all) {
-            if (m_pCPart->m_SvnWrapper->isLocalWorkingCopy(KUrl::fromLocalFile(tmpurl.path()), _baseurl)) {
+            QUrl repoUrl;
+            if (m_pCPart->m_SvnWrapper->isLocalWorkingCopy(tmpurl.path(), repoUrl)) {
                 tmp = tmpurl.path();
-                m_pCPart->baseUrls[j - 2] = _baseurl;
+                m_pCPart->repoUrls[j - 2] = repoUrl;
                 m_pCPart->extraRevisions[j - 2] = svn::Revision::WORKING;
                 if (j == 2) {
                     mainProto.clear();
@@ -256,7 +254,7 @@ int CommandExec::exec(KCmdLineArgs *args)
         } else {
             tmp = tmpurl.url();
             if (j == 2) {
-                mainProto = tmpurl.protocol();
+                mainProto = tmpurl.scheme();
             }
         }
         if ((j > 2 && dont_check_second) || dont_check_all) {
@@ -264,45 +262,50 @@ int CommandExec::exec(KCmdLineArgs *args)
                 tmp = tmpurl.path();
             }
         }
-        QStringList l = tmp.split(QLatin1Char('?'), QString::SkipEmptyParts);
+        const QStringList l = tmp.split(QLatin1Char('?'), QString::SkipEmptyParts);
         if (!l.isEmpty()) {
             tmp = l[0];
         }
         while (tmp.endsWith(QLatin1Char('/'))) {
             tmp.chop(1);
         }
-        m_pCPart->url.append(tmp);
+        m_pCPart->urls.append(tmp);
         if ((j > 2 && dont_check_second) || dont_check_all) {
             continue;
         }
-        svn::Revision re = v;
-        if (re) {
-            m_pCPart->extraRevisions[j - 2] = re;
+        const QList<QPair<QString, QString> > q = QUrlQuery(tmpurl).queryItems();
+        for(int i = 0; i < q.size(); ++i) {
+            if (q.at(i).first == QLatin1String("rev")) {
+                svn::Revision re = q.at(i).second;
+                if (re) {
+                    m_pCPart->extraRevisions[j - 2] = re;
+                }
+            }
         }
     }
-    if (m_pCPart->url.count() == 0) {
-        m_pCPart->url.append(".");
+    if (m_pCPart->urls.isEmpty()) {
+        m_pCPart->urls.append(QLatin1String("."));
     }
 
     if (!no_revision) {
-        if (m_pCPart->args->isSet("R")) {
+        if (m_pCPart->parser->isSet("R")) {
             m_pCPart->ask_revision = true;
             if (!askRevision()) {
                 return 0;
             }
-        } else if (m_pCPart->args->isSet("r")) {
+        } else if (m_pCPart->parser->isSet("r")) {
             scanRevision();
         }
     }
 
-    m_pCPart->force = check_force && m_pCPart->args->isSet("f");
+    m_pCPart->force = check_force && m_pCPart->parser->isSet("f");
 
-    if (m_pCPart->args->isSet("o")) {
+    if (m_pCPart->parser->isSet("o")) {
         m_pCPart->outfile_set = true;
-        m_pCPart->outfile = m_pCPart->args->getOption("o");
+        m_pCPart->outfile = m_pCPart->parser->value("o");
     }
-    if (m_pCPart->args->isSet("l")) {
-        QString s = m_pCPart->args->getOption("l");
+    if (m_pCPart->parser->isSet("l")) {
+        QString s = m_pCPart->parser->value("l");
         m_pCPart->log_limit = s.toInt();
         if (m_pCPart->log_limit < 0) {
             m_pCPart->log_limit = 0;
@@ -312,22 +315,21 @@ int CommandExec::exec(KCmdLineArgs *args)
     emit executeMe();
     if (Kdesvnsettings::self()->cmdline_show_logwindow() &&
             m_lastMessagesLines >= Kdesvnsettings::self()->cmdline_log_minline()) {
-        QPointer<KDialog> dlg(new KDialog(KApplication::activeModalWidget()));
-        KVBox *Dialog1Layout = new KVBox(dlg);
-        dlg->setMainWidget(Dialog1Layout);
-        KTextBrowser *ptr = new KTextBrowser(Dialog1Layout);
+        QPointer<KSvnSimpleOkDialog> dlg(new KSvnSimpleOkDialog(QStringLiteral("kdesvn_cmd_log"), QApplication::activeModalWidget()));
+        QTextBrowser *ptr = new QTextBrowser(dlg);
         ptr->setText(m_lastMessages);
-        KConfigGroup _k(Kdesvnsettings::self()->config(), "kdesvn_cmd_log");
-        dlg->restoreDialogSize(_k);
+        ptr->setReadOnly(true);
+        dlg->addWidget(ptr);
+        QString cmd = qApp->arguments().join(QLatin1Char(' '));
+        dlg->setWindowTitle(cmd);
         dlg->exec();
-        if (dlg) {
-            dlg->saveDialogSize(_k);
-            delete dlg;
-        }
+        delete dlg;
     }
     return 0;
 }
 
+
+
 /*!
     \fn CommandExec::clientException(const QString&)
  */
@@ -337,6 +339,7 @@ void CommandExec::clientException(const QString &what)
     KMessageBox::sorry(0, what, i18n("SVN Error"));
 }
 
+
 void CommandExec::slotCmd_log()
 {
     int limit = m_pCPart->log_limit;
@@ -350,7 +353,9 @@ void CommandExec::slotCmd_log()
     if (m_pCPart->extraRevisions[0] == svn::Revision::WORKING) {
         m_pCPart->extraRevisions[0] = svn::Revision::UNDEFINED;
     }
-    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start, m_pCPart->end, m_pCPart->extraRevisions[0], m_pCPart->url[0],
+    m_pCPart->m_SvnWrapper->makeLog(m_pCPart->start, m_pCPart->end,
+                                    m_pCPart->extraRevisions.value(0),
+                                    m_pCPart->urls.at(0),
                                     Kdesvnsettings::log_follows_nodes(),
                                     list,
                                     limit);
@@ -364,27 +369,32 @@ void CommandExec::slotCmd_tree()
     if (m_pCPart->start == svn::Revision::UNDEFINED) {
         m_pCPart->start = 1;
     }
-    m_pCPart->m_SvnWrapper->makeTree(m_pCPart->url[0], m_pCPart->extraRevisions[0], m_pCPart->start, m_pCPart->end);
+    m_pCPart->m_SvnWrapper->makeTree(m_pCPart->urls.at(0), m_pCPart->extraRevisions.value(0),
+                                     m_pCPart->start, m_pCPart->end);
 }
 
 void CommandExec::slotCmd_checkout()
 {
-    m_pCPart->m_SvnWrapper->CheckoutExport(m_pCPart->url[0], false);
+    m_pCPart->m_SvnWrapper->CheckoutExport(QUrl::fromUserInput(m_pCPart->urls.at(0),
+                                                               QDir::currentPath()), false);
 }
 
 void CommandExec::slotCmd_checkoutto()
 {
-    m_pCPart->m_SvnWrapper->CheckoutExport(m_pCPart->url[0], false, true);
+    m_pCPart->m_SvnWrapper->CheckoutExport(QUrl::fromUserInput(m_pCPart->urls.at(0),
+                                                               QDir::currentPath()), false, true);
 }
 
 void CommandExec::slotCmd_export()
 {
-    m_pCPart->m_SvnWrapper->CheckoutExport(m_pCPart->url[0], true);
+    m_pCPart->m_SvnWrapper->CheckoutExport(QUrl::fromUserInput(m_pCPart->urls.at(0),
+                                                               QDir::currentPath()), true);
 }
 
 void CommandExec::slotCmd_exportto()
 {
-    m_pCPart->m_SvnWrapper->CheckoutExport(m_pCPart->url[0], true, true);
+    m_pCPart->m_SvnWrapper->CheckoutExport(QUrl::fromUserInput(m_pCPart->urls.at(0),
+                                                               QDir::currentPath()), true, true);
 }
 
 void CommandExec::slotCmd_blame()
@@ -395,19 +405,20 @@ void CommandExec::slotCmd_blame()
     if (!m_pCPart->start) {
         m_pCPart->start = 1;
     }
-    m_pCPart->m_SvnWrapper->makeBlame(m_pCPart->start, m_pCPart->end, m_pCPart->url[0]);
+    m_pCPart->m_SvnWrapper->makeBlame(m_pCPart->start, m_pCPart->end, m_pCPart->urls.at(0));
 }
 
 void CommandExec::slotCmd_cat()
 {
-    if (m_pCPart->extraRevisions.find(0) != m_pCPart->extraRevisions.end()) {
+    QMap<int, svn::Revision>::const_iterator cIt = m_pCPart->extraRevisions.constFind(0);
+    if (cIt != m_pCPart->extraRevisions.constEnd()) {
         m_pCPart->rev_set = true;
-        m_pCPart->start = m_pCPart->extraRevisions[0];
+        m_pCPart->start = cIt.value();
     } else {
         m_pCPart->end = svn::Revision::HEAD;
     }
     m_pCPart->m_SvnWrapper->slotMakeCat(
-        (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), m_pCPart->url[0], m_pCPart->url[0]
+        (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), m_pCPart->urls.at(0), m_pCPart->urls.at(0)
         , (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), 0);
 }
 
@@ -423,57 +434,58 @@ void CommandExec::slotCmd_get()
         clientException(i18n("\"GET\" requires output file"));
         return;
     }
-    m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), m_pCPart->url[0], m_pCPart->outfile,
+    m_pCPart->m_SvnWrapper->makeGet((m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), m_pCPart->urls.at(0), m_pCPart->outfile,
                                     (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end));
 }
 
 void CommandExec::slotCmd_update()
 {
-    m_pCPart->m_SvnWrapper->makeUpdate(m_pCPart->url,
+    const svn::Targets targets = svn::Targets::fromStringList(m_pCPart->urls);
+    m_pCPart->m_SvnWrapper->makeUpdate(targets,
                                        (m_pCPart->rev_set ? m_pCPart->start : svn::Revision::HEAD), svn::DepthUnknown);
 }
 
 void CommandExec::slotCmd_diff()
 {
-    if (m_pCPart->url.count() == 1) {
-        if (!m_pCPart->rev_set && !svn::Url::isValid(m_pCPart->url[0])) {
+    if (m_pCPart->urls.count() == 1) {
+        if (!m_pCPart->rev_set && !svn::Url::isValid(m_pCPart->urls.at(0))) {
             m_pCPart->start = svn::Revision::BASE;
             m_pCPart->end = svn::Revision::WORKING;
         }
-        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0], m_pCPart->start, m_pCPart->url[0], m_pCPart->end);
+        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->urls.at(0), m_pCPart->start, m_pCPart->urls.at(0), m_pCPart->end);
     } else {
         svn::Revision r1 = svn::Revision::HEAD;
         svn::Revision r2 = svn::Revision::HEAD;
-        if (m_pCPart->extraRevisions.find(0) != m_pCPart->extraRevisions.end()) {
-            r1 = m_pCPart->extraRevisions[0];
-        } else if (!svn::Url::isValid(m_pCPart->url[0])) {
+        QMap<int, svn::Revision>::const_iterator cIt = m_pCPart->extraRevisions.constFind(0);
+        if (cIt != m_pCPart->extraRevisions.constEnd()) {
+            r1 = cIt.value();
+        } else if (!svn::Url::isValid(m_pCPart->urls.at(0))) {
             r1 = svn::Revision::WORKING;
         }
         if (m_pCPart->extraRevisions.find(1) != m_pCPart->extraRevisions.end()) {
             r2 = m_pCPart->extraRevisions[1];
-        } else if (!svn::Url::isValid(m_pCPart->url[1])) {
+        } else if (!svn::Url::isValid(m_pCPart->urls.at(1))) {
             r2 = svn::Revision::WORKING;
         }
-        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->url[0], r1, m_pCPart->url[1], r2);
+        m_pCPart->m_SvnWrapper->makeDiff(m_pCPart->urls.at(0), r1, m_pCPart->urls.at(1), r2);
     }
 }
 
 void CommandExec::slotCmd_info()
 {
-    if (m_pCPart->extraRevisions.find(0) != m_pCPart->extraRevisions.end()) {
+    QMap<int, svn::Revision>::const_iterator cIt = m_pCPart->extraRevisions.constFind(0);
+    if (cIt != m_pCPart->extraRevisions.constEnd()) {
         m_pCPart->rev_set = true;
-        m_pCPart->start = m_pCPart->extraRevisions[0];
+        m_pCPart->start = cIt.value();
     }
-    m_pCPart->m_SvnWrapper->makeInfo(m_pCPart->url, (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end), svn::Revision::UNDEFINED, false);
+    m_pCPart->m_SvnWrapper->makeInfo(m_pCPart->urls, (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end),
+                                     svn::Revision::UNDEFINED, false);
 }
 
 void CommandExec::slotCmd_commit()
 {
-    QStringList targets;
-    for (long j = 0; j < m_pCPart->url.count(); ++j) {
-        targets.push_back(svn::Path(m_pCPart->url[j]));
-    }
-    m_pCPart->m_SvnWrapper->makeCommit(svn::Targets(targets));
+    const svn::Targets targets(svn::Targets::fromStringList(m_pCPart->urls));
+    m_pCPart->m_SvnWrapper->makeCommit(targets);
 }
 
 void CommandExec::slotCmd_list()
@@ -485,11 +497,11 @@ void CommandExec::slotCmd_list()
     } else if (m_pCPart->extraRevisions[0]) {
         rev = m_pCPart->extraRevisions[0];
     }
-    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->url[0], res, rev, svn::DepthInfinity)) {
+    if (!m_pCPart->m_SvnWrapper->makeList(m_pCPart->urls.at(0), res, rev, svn::DepthInfinity)) {
         return;
     }
     Q_FOREACH(const svn::DirEntry &entry, res) {
-        QString d = svn::DateTime(entry.time()).toString(QString("yyyy-MM-dd hh:mm::ss"));
+        QString d = entry.time().toString(QStringLiteral("yyyy-MM-dd hh:mm::ss"));
         m_pCPart->Stdout
                 << (entry.kind() == svn_node_dir ? "D" : "F") << " "
                 << d << " "
@@ -500,60 +512,60 @@ void CommandExec::slotCmd_list()
 void CommandExec::slotCmd_copy()
 {
     QString target;
-    if (m_pCPart->url.count() < 2) {
-        bool force_move, ok;
-        target = CopyMoveView_impl::getMoveCopyTo(&ok, &force_move, false,
-                 m_pCPart->url[0], QString(), 0);
+    if (m_pCPart->urls.count() < 2) {
+        bool ok;
+        target = CopyMoveView_impl::getMoveCopyTo(&ok, false,
+                                                  m_pCPart->urls.at(0), QString(), 0);
         if (!ok) {
             return;
         }
     } else {
-        target = m_pCPart->url[1];
+        target = m_pCPart->urls.at(1);
     }
-    if (m_pCPart->extraRevisions.find(0) != m_pCPart->extraRevisions.end()) {
+    QMap<int, svn::Revision>::const_iterator cIt = m_pCPart->extraRevisions.constFind(0);
+    if (cIt != m_pCPart->extraRevisions.constEnd()) {
         m_pCPart->rev_set = true;
-        m_pCPart->start = m_pCPart->extraRevisions[0];
+        m_pCPart->start = cIt.value();
     } else {
         m_pCPart->end = svn::Revision::HEAD;
     }
-    m_pCPart->m_SvnWrapper->makeCopy(m_pCPart->url[0], target, (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end));
+    m_pCPart->m_SvnWrapper->makeCopy(m_pCPart->urls.at(0), target, (m_pCPart->rev_set ? m_pCPart->start : m_pCPart->end));
 }
 
 void CommandExec::slotCmd_move()
 {
-    bool force_move, ok;
-    force_move = false;
+    bool ok;
     QString target;
-    if (m_pCPart->url.count() < 2) {
-        target = CopyMoveView_impl::getMoveCopyTo(&ok, &force_move, true,
-                 m_pCPart->url[0], QString(), 0);
+    if (m_pCPart->urls.count() < 2) {
+        target = CopyMoveView_impl::getMoveCopyTo(&ok, true,
+                                                  m_pCPart->urls.at(0), QString(), 0);
         if (!ok) {
             return;
         }
     } else {
-        target = m_pCPart->url[1];
+        target = m_pCPart->urls.at(1);
     }
-    m_pCPart->m_SvnWrapper->makeMove(m_pCPart->url[0], target, force_move);
+    m_pCPart->m_SvnWrapper->makeMove(m_pCPart->urls.at(0), target);
 }
 
 void CommandExec::slotCmd_delete()
 {
-    m_pCPart->m_SvnWrapper->makeDelete(m_pCPart->url);
+    m_pCPart->m_SvnWrapper->makeDelete(m_pCPart->urls);
 }
 
 void CommandExec::slotCmd_add()
 {
-    m_pCPart->m_SvnWrapper->addItems(helpers::sub2qt::fromStringList(m_pCPart->url), svn::DepthInfinity);
+    m_pCPart->m_SvnWrapper->addItems(svn::Targets::fromStringList(m_pCPart->urls), svn::DepthInfinity);
 }
 
 void CommandExec::slotCmd_revert()
 {
-    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->url, false);
+    m_pCPart->m_SvnWrapper->slotRevertItems(m_pCPart->urls);
 }
 
 void CommandExec::slotCmd_addnew()
 {
-    m_pCPart->m_SvnWrapper->checkAddItems(m_pCPart->url[0]);
+    m_pCPart->m_SvnWrapper->checkAddItems(m_pCPart->urls.at(0));
 }
 
 /*!
@@ -561,7 +573,7 @@ void CommandExec::slotCmd_addnew()
  */
 bool CommandExec::scanRevision()
 {
-    QString revstring = m_pCPart->args->getOption("r");
+    QString revstring = m_pCPart->parser->value("r");
     QStringList revl = revstring.split(':', QString::SkipEmptyParts);
     if (revl.count() == 0) {
         return false;
@@ -588,53 +600,43 @@ void CommandExec::slotNotifyMessage(const QString &msg)
 
 bool CommandExec::askRevision()
 {
-    QPointer<KDialog> dlg(new KDialog(0));
-    dlg->setCaption(i18n("Revision"));
-    dlg->setButtons(KDialog::Ok | KDialog::Cancel);
-    KVBox *Dialog1Layout = new KVBox(dlg);
-    dlg->setMainWidget(Dialog1Layout);
-
     bool ret = false;
-    Rangeinput_impl *rdlg = new Rangeinput_impl(Dialog1Layout);
-    dlg->resize(QSize(120, 60).expandedTo(dlg->minimumSizeHint()));
-    rdlg->setStartOnly(m_pCPart->single_revision);
-    if (dlg->exec() == KDialog::Accepted) {
-        Rangeinput_impl::revision_range range = rdlg->getRange();
+    Rangeinput_impl::revision_range range;
+    if (Rangeinput_impl::getRevisionRange(range, true, m_pCPart->single_revision)) {
         m_pCPart->start = range.first;
         m_pCPart->end = range.second;
         m_pCPart->rev_set = true;
         ret = true;
     }
-    delete dlg;
     return ret;
 }
 
+
 /*!
     \fn CommandExec::slotCmd_switch()
  */
 void CommandExec::slotCmd_switch()
 {
-    QString base;
-    if (m_pCPart->url.count() > 1) {
+    if (m_pCPart->urls.count() > 1) {
         clientException(i18n("May only switch one URL at time"));
         return;
     }
-    if (m_pCPart->baseUrls.find(0) == m_pCPart->baseUrls.end()) {
+    if (m_pCPart->repoUrls.find(0) == m_pCPart->repoUrls.end()) {
         clientException(i18n("Switch only on working copies"));
         return;
     }
-    base = m_pCPart->baseUrls[0];
-    m_pCPart->m_SvnWrapper->makeSwitch(m_pCPart->url[0], base);
+    m_pCPart->m_SvnWrapper->makeSwitch(m_pCPart->urls.at(0),
+                                       m_pCPart->repoUrls.value(0));
 }
 
 void CommandExec::slotCmd_lock()
 {
-//     m_pCPart->m_SvnWrapper->makeLock(m_pCPart->url[0],"",m_pCPart->force);
-    m_pCPart->m_SvnWrapper->makeLock(m_pCPart->url, QString(), m_pCPart->force);
+//     m_pCPart->m_SvnWrapper->makeLock(m_pCPart->urls.at(0),"",m_pCPart->force);
+    m_pCPart->m_SvnWrapper->makeLock(m_pCPart->urls, QString(), m_pCPart->force);
 }
 
 void CommandExec::slotCmd_unlock()
 {
-//     m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->url[0],m_pCPart->force);
-    m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->url, m_pCPart->force);
+//     m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->urls.at(0),m_pCPart->force);
+    m_pCPart->m_SvnWrapper->makeUnlock(m_pCPart->urls, m_pCPart->force);
 }
