@@ -23,26 +23,25 @@
  ***************************************************************************/
 #include "LogCache.h"
 
-#include <qdir.h>
-#include <qsql.h>
-#include <qsqldatabase.h>
-
+#include <QDebug>
+#include <QDir>
+#include <QMap>
 #include <QMutex>
 #include <QThreadStorage>
+#include <QSqlDatabase>
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QVariant>
-#include <qmap.h>
-#include <QtDebug>
 
 #include "svnqt/path.h"
 #include "svnqt/cache/DatabaseException.h"
 
-#define SQLTYPE "QSQLITE"
-#define SQLMAIN "logmain-logcache"
-#define SQLMAINTABLE "logdb"
-#define SQLREPOSPARAMETER "repoparameter"
-#define SQLSTATUS QString("logstatus")
+static QString SQLTYPE() { return QStringLiteral("QSQLITE"); }
+static QString SQLMAIN() { return QStringLiteral("logmain-logcache"); }
+static QString SQLMAINTABLE() { return QStringLiteral("logdb"); }
+static QString SQLTMPDB() { return QStringLiteral("tmpdb"); }
+static QString SQLREPOSPARAMETER() { return QStringLiteral("repoparameter"); }
+static QString SQLSTATUS() { return QStringLiteral("logstatus"); }
 
 namespace svn
 {
@@ -111,17 +110,17 @@ public:
         }
     }
 
-    QString idToPath(const QString &id)
+    QString idToPath(const QString &id) const
     {
-        return m_BasePath + '/' + id + ".db";
+        return m_BasePath + QLatin1Char('/') + id + QLatin1String(".db");
     }
 
     bool deleteRepository(const QString &aRepository)
     {
-        QString id = getReposId(aRepository);
+        const QString id = getReposId(aRepository);
 
-        static QString s_q(QString("delete from ") + QString(SQLREPOSPARAMETER) + " where id = ?");
-        static QString r_q(QString("delete from ") + QString(SQLMAINTABLE) + " where id = ?");
+        static const QString s_q(QLatin1String("delete from ") + SQLREPOSPARAMETER() + QLatin1String(" where id = ?"));
+        static const QString r_q(QLatin1String("delete from ") + SQLMAINTABLE() + QLatin1String(" where id = ?"));
         QSqlDatabase mainDB = getMainDB();
         if (!mainDB.isValid()) {
             qWarning("Failed to open main database.");
@@ -169,51 +168,48 @@ public:
         QSqlQuery _q(aDb);
         QStringList list = aDb.tables();
 
-        if (list.indexOf("logentries") == -1) {
-            aDb.transaction();
-            _q.exec("CREATE TABLE \"logentries\" (\"idx\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, \"revision\" INTEGER UNIQUE,\"date\" INTEGER,\"author\" TEXT, \"message\" TEXT)");
-            aDb.commit();
+        aDb.transaction();
+        if (!list.contains(QStringLiteral("logentries"))) {
+            _q.exec(QStringLiteral("CREATE TABLE \"logentries\" (\"idx\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, \"revision\" INTEGER UNIQUE,\"date\" INTEGER,\"author\" TEXT, \"message\" TEXT)"));
         }
-        if (list.indexOf("changeditems") == -1) {
-            aDb.transaction();
-            _q.exec("CREATE TABLE \"changeditems\" (\"idx\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, \"revision\" INTEGER,\"changeditem\" TEXT,\"action\" TEXT,\"copyfrom\" TEXT,\"copyfromrev\" INTEGER, UNIQUE(revision,changeditem,action))");
-            aDb.commit();
+        if (!list.contains(QStringLiteral("changeditems"))) {
+            _q.exec(QStringLiteral("CREATE TABLE \"changeditems\" (\"idx\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, \"revision\" INTEGER,\"changeditem\" TEXT,\"action\" TEXT,\"copyfrom\" TEXT,\"copyfromrev\" INTEGER, UNIQUE(revision,changeditem,action))"));
         }
-        if (list.indexOf("mergeditems") == -1) {
-            aDb.transaction();
-            _q.exec("CREATE TABLE \"mergeditems\" (\"revision\" INTEGER,\"mergeditems\" TEXT, PRIMARY KEY(revision))");
-            aDb.commit();
+        if (!list.contains(QStringLiteral("mergeditems"))) {
+            _q.exec(QStringLiteral("CREATE TABLE \"mergeditems\" (\"revision\" INTEGER,\"mergeditems\" TEXT, PRIMARY KEY(revision))"));
         }
-        if (list.indexOf("dbversion") == -1) {
-            aDb.transaction();
-            _q.exec("CREATE TABLE \"dbversion\" (\"version\" INTEGER)");
+        if (!list.contains(QStringLiteral("dbversion"))) {
+            _q.exec(QStringLiteral("CREATE TABLE \"dbversion\" (\"version\" INTEGER)"));
             qDebug() << _q.lastError();
-            _q.exec("insert into \"dbversion\" (version) values(0)");
-            aDb.commit();
+            _q.exec(QStringLiteral("INSERT INTO \"dbversion\" (version) VALUES(0)"));
         }
+        aDb.commit();
         list = aDb.tables();
-        if (list.indexOf("logentries") == -1 || list.indexOf("changeditems") == -1 || list.indexOf("mergeditems") == -1 || list.indexOf("dbversion") == -1) {
+        if (!list.contains(QStringLiteral("logentries")) ||
+            !list.contains(QStringLiteral("changeditems")) ||
+            !list.contains(QStringLiteral("mergeditems")) ||
+            !list.contains(QStringLiteral("dbversion"))) {
             qDebug() << "lists: " << list;
             return false;
         }
-        _q.exec("SELECT VERSION from dbversion limit 1");
+        _q.exec(QStringLiteral("SELECT VERSION from dbversion limit 1"));
         if (_q.lastError().type() == QSqlError::NoError && _q.next()) {
             int version = _q.value(0).toInt();
             if (version == 0) {
-                _q.exec("create index if not exists main.authorindex on logentries(author)");
+                _q.exec(QStringLiteral("create index if not exists main.authorindex on logentries(author)"));
                 if (_q.lastError().type() != QSqlError::NoError) {
                     qDebug() << _q.lastError();
                 } else {
-                    _q.exec("UPDATE dbversion SET VERSION=1");
+                    _q.exec(QStringLiteral("UPDATE dbversion SET VERSION=1"));
                 }
                 ++version;
             }
             if (version == 1) {
-                _q.exec("create index if not exists main.dateindex on logentries(date)");
+                _q.exec(QStringLiteral("create index if not exists main.dateindex on logentries(date)"));
                 if (_q.lastError().type() != QSqlError::NoError) {
                     qDebug() << _q.lastError();
                 } else {
-                    _q.exec("UPDATE dbversion SET VERSION=2");
+                    _q.exec(QStringLiteral("UPDATE dbversion SET VERSION=2"));
                 }
                 ++version;
             }
@@ -231,14 +227,14 @@ public:
 
         _mdb.transaction();
         QSqlQuery query(_mdb);
-        QString q(QLatin1String("insert into ") + QLatin1String(SQLMAINTABLE) + QLatin1String(" (reposroot) VALUES('") + reposroot.path() + QLatin1String("')"));
+        QString q(QLatin1String("insert into ") + SQLMAINTABLE() + QLatin1String(" (reposroot) VALUES('") + reposroot.path() + QLatin1String("')"));
 
         if (!query.exec(q)) {
             return QString();
         }
 
         _mdb.commit();
-        query.prepare(s_reposSelect);
+        query.prepare(reposSelect());
         query.bindValue(0, reposroot.native());
         QString db;
         if (query.exec() && query.next()) {
@@ -248,11 +244,11 @@ public:
         }
         if (!db.isEmpty()) {
             QString fulldb = idToPath(db);
-            QSqlDatabase _db = QSqlDatabase::addDatabase(SQLTYPE, "tmpdb");
+            QSqlDatabase _db = QSqlDatabase::addDatabase(SQLTYPE(), SQLTMPDB());
             _db.setDatabaseName(fulldb);
             if (!checkReposDb(_db)) {
             }
-            QSqlDatabase::removeDatabase("tmpdb");
+            QSqlDatabase::removeDatabase(SQLTMPDB());
         }
         return db;
     }
@@ -263,7 +259,7 @@ public:
             return QString();
         }
         QSqlQuery c(getMainDB());
-        c.prepare(s_reposSelect);
+        c.prepare(reposSelect());
         c.bindValue(0, reposroot.native());
 
         // only the first one
@@ -286,39 +282,37 @@ public:
                 return QSqlDatabase();
             }
         }
-        QSqlDatabase _db;
         if (m_mainDB.localData()->reposCacheNames.find(dbFile) != m_mainDB.localData()->reposCacheNames.end()) {
-            _db = QSqlDatabase::database(m_mainDB.localData()->reposCacheNames[dbFile]);
-            checkReposDb(_db);
-            return _db;
+            QSqlDatabase db = QSqlDatabase::database(m_mainDB.localData()->reposCacheNames.value(dbFile));
+            checkReposDb(db);
+            return db;
         }
-        int i = 0;
+        unsigned i = 0;
         QString _key = dbFile;
         while (QSqlDatabase::contains(_key)) {
-            _key = QString("%1-%2").arg(dbFile).arg(i++);
+            _key = QStringLiteral("%1-%2").arg(dbFile).arg(i++);
         }
-        _db = QSqlDatabase::addDatabase(SQLTYPE, _key);
-        QString fulldb = idToPath(dbFile);
-        _db.setDatabaseName(fulldb);
-        if (!checkReposDb(_db)) {
-            _db = QSqlDatabase();
+        const QString fulldb = idToPath(dbFile);
+        QSqlDatabase db = QSqlDatabase::addDatabase(SQLTYPE(), _key);
+        db.setDatabaseName(fulldb);
+        if (!checkReposDb(db)) {
+            db = QSqlDatabase();
         } else {
             m_mainDB.localData()->reposCacheNames[dbFile] = _key;
         }
-        return _db;
+        return db;
     }
 
     QSqlDatabase getMainDB()const
     {
         if (!m_mainDB.hasLocalData()) {
             unsigned i = 0;
-            QString _key = SQLMAIN;
+            QString _key = SQLMAIN();
             while (QSqlDatabase::contains(_key)) {
-                _key.sprintf("%s-%i", SQLMAIN, i++);
+                _key = QStringLiteral("%1-%2").arg(SQLMAIN()).arg(i++);
             }
-
-            QSqlDatabase db = QSqlDatabase::addDatabase(SQLTYPE, _key);
-            db.setDatabaseName(m_BasePath + "/maindb.db");
+            QSqlDatabase db = QSqlDatabase::addDatabase(SQLTYPE(), _key);
+            db.setDatabaseName(m_BasePath + QLatin1String("/maindb.db"));
             if (db.open()) {
                 m_mainDB.setLocalData(new ThreadDBStore);
                 m_mainDB.localData()->key = _key;
@@ -335,29 +329,29 @@ public:
 
     mutable QThreadStorage<ThreadDBStore *> m_mainDB;
 
-    static const QString s_reposSelect;
+    static QString reposSelect()
+    {
+        return QStringLiteral("SELECT id from ") +
+            SQLMAINTABLE() +
+            QStringLiteral(" where reposroot=? ORDER by id DESC");
+    }
 };
 
-QString LogCache::s_CACHE_FOLDER = "logcache";
-const QString LogCacheData::s_reposSelect = QString("SELECT id from ") + QString(SQLMAINTABLE) + QString(" where reposroot=? ORDER by id DESC");
-
 /*!
     \fn svn::cache::LogCache::LogCache()
  */
 LogCache::LogCache()
+    : m_BasePath(QDir::homePath() + QLatin1String("/.svnqt"))
 {
-    m_BasePath = QDir::homePath() + "/.svnqt";
     setupCachePath();
 }
 
 LogCache::LogCache(const QString &aBasePath)
 {
-    if (mSelf) {
-        delete mSelf;
-    }
+    delete mSelf;
     mSelf = this;
     if (aBasePath.isEmpty()) {
-        m_BasePath = QDir::homePath() + "/.svnqt";
+        m_BasePath = QDir::homePath() + QLatin1String("/.svnqt");
     } else {
         m_BasePath = aBasePath;
     }
@@ -379,7 +373,7 @@ void LogCache::setupCachePath()
     if (!d.exists(m_BasePath)) {
         d.mkdir(m_BasePath);
     }
-    m_BasePath = m_BasePath + '/' + s_CACHE_FOLDER;
+    m_BasePath = m_BasePath + QLatin1Char('/') + QLatin1String("logcache");
     if (!d.exists(m_BasePath)) {
         d.mkdir(m_BasePath);
     }
@@ -397,18 +391,18 @@ void LogCache::setupMainDb()
     } else {
         QStringList list = mainDB.tables();
         QSqlQuery q(mainDB);
-        if (list.indexOf(SQLSTATUS) == -1) {
+        if (list.indexOf(SQLSTATUS()) == -1) {
             mainDB.transaction();
-            if (q.exec("CREATE TABLE \"" + SQLSTATUS + "\" (\"key\" TEXT PRIMARY KEY NOT NULL, \"value\" TEXT);")) {
-                q.exec("INSERT INTO \"" + SQLSTATUS + "\" (key,value) values(\"version\",\"0\");");
+            if (q.exec(QLatin1String("CREATE TABLE \"") + SQLSTATUS() + QLatin1String("\" (\"key\" TEXT PRIMARY KEY NOT NULL, \"value\" TEXT);"))) {
+                q.exec(QLatin1String("INSERT INTO \"") + SQLSTATUS() + QLatin1String("\" (key,value) values(\"version\",\"0\");"));
             }
             mainDB.commit();
         }
         int version = databaseVersion();
         if (version == 0) {
             mainDB.transaction();
-            if (list.indexOf(SQLMAINTABLE) == -1) {
-                q.exec("CREATE TABLE IF NOT EXISTS \"" + QString(SQLMAINTABLE) + "\" (\"reposroot\" TEXT,\"id\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL);");
+            if (list.indexOf(SQLMAINTABLE()) == -1) {
+                q.exec(QLatin1String("CREATE TABLE IF NOT EXISTS \"") + SQLMAINTABLE() + QLatin1String("\" (\"reposroot\" TEXT,\"id\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL);"));
             }/* else {
                 q.exec("CREATE TABLE IF NOT EXISTS \""+QString(SQLMAINTABLE)+"new\" (\"reposroot\" TEXT,\"id\" INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL);");
                 q.exec("insert into \""+QString(SQLMAINTABLE)+"new\" select \"reposroot\",\"id\" from \""+QString(SQLMAINTABLE)+"\");");
@@ -419,7 +413,8 @@ void LogCache::setupMainDb()
         }
         if (version == 1) {
             mainDB.transaction();
-            if (!q.exec("CREATE TABLE IF NOT EXISTS \"" + QString(SQLREPOSPARAMETER) + "\" (\"id\" INTEGER NOT NULL, \"parameter\" TEXT, \"value\" TEXT, PRIMARY KEY(\"id\",\"parameter\"));")) {
+            if (!q.exec(QLatin1String("CREATE TABLE IF NOT EXISTS \"") + SQLREPOSPARAMETER() +
+                        QLatin1String("\" (\"id\" INTEGER NOT NULL, \"parameter\" TEXT, \"value\" TEXT, PRIMARY KEY(\"id\",\"parameter\"));"))) {
                 qDebug() << "Error create: " << q.lastError().text() << "(" << q.lastQuery() << ")";
             }
             mainDB.commit();
@@ -435,7 +430,7 @@ void LogCache::databaseVersion(int newversion)
     if (!mainDB.isValid()) {
         return;
     }
-    static QString _qs("update \"" + SQLSTATUS + "\" SET value = ? WHERE \"key\" = \"version\"");
+    static const QString _qs(QLatin1String("update \"") + SQLSTATUS() + QLatin1String("\" SET value = ? WHERE \"key\" = \"version\""));
     QSqlQuery cur(mainDB);
     cur.prepare(_qs);
     cur.bindValue(0, newversion);
@@ -450,7 +445,7 @@ int LogCache::databaseVersion()const
     if (!mainDB.isValid()) {
         return -1;
     }
-    static QString _qs("select value from \"" + SQLSTATUS + "\" WHERE \"key\" = \"version\"");
+    static const QString _qs(QLatin1String("select value from \"") + SQLSTATUS() + QLatin1String("\" WHERE \"key\" = \"version\""));
     QSqlQuery cur(mainDB);
     cur.prepare(_qs);
     if (!cur.exec()) {
@@ -470,7 +465,10 @@ QVariant LogCache::getRepositoryParameter(const svn::Path &repository, const QSt
     if (!mainDB.isValid()) {
         return QVariant();
     }
-    static QString qs("select \"value\",\"repoparameter\".\"parameter\" as \"key\" from \"" + QString(SQLREPOSPARAMETER) + "\" INNER JOIN \"" + QString(SQLMAINTABLE) + "\" ON (\"" + QString(SQLREPOSPARAMETER) + "\".id = \"" + QString(SQLMAINTABLE) + "\".id and \"" + QString(SQLMAINTABLE) + "\".reposroot = ?)  WHERE \"parameter\" = ?;");
+    static const QString qs(QLatin1String("select \"value\",\"repoparameter\".\"parameter\" as \"key\" from \"") + SQLREPOSPARAMETER() +
+                            QLatin1String("\" INNER JOIN \"") + SQLMAINTABLE() + QLatin1String("\" ON (\"") + SQLREPOSPARAMETER() +
+                            QLatin1String("\".id = \"") + SQLMAINTABLE() + QLatin1String("\".id and \"") + SQLMAINTABLE() +
+                            QLatin1String("\".reposroot = ?)  WHERE \"parameter\" = ?;"));
     QSqlQuery cur(mainDB);
     cur.prepare(qs);
     cur.bindValue(0, repository.native());
@@ -495,12 +493,14 @@ bool LogCache::setRepositoryParameter(const svn::Path &repository, const QString
     if (id.isEmpty()) {
         return false;
     }
-    static QString qs("INSERT OR REPLACE INTO \"" + QString(SQLREPOSPARAMETER) + "\" (\"id\",\"parameter\",\"value\") values (\"%1\",\"%2\",?);");
-    static QString dqs("DELETE FROM \"" + QString(SQLREPOSPARAMETER) + "\" WHERE \"id\"=? and \"parameter\" = ?");
+    static const QString qs(QLatin1String("INSERT OR REPLACE INTO \"") + SQLREPOSPARAMETER() +
+                            QLatin1String("\" (\"id\",\"parameter\",\"value\") values (\"%1\",\"%2\",?);"));
+    static const QString dqs(QLatin1String("DELETE FROM \"") + SQLREPOSPARAMETER() +
+                             QLatin1String("\" WHERE \"id\"=? and \"parameter\" = ?"));
     mainDB.transaction();
     QSqlQuery cur(mainDB);
     if (value.isValid()) {
-        QString _qs = qs.arg(id).arg(key);//.arg(value.toByteArray());
+        QString _qs = qs.arg(id,key);//.arg(value.toByteArray());
         cur.prepare(_qs);
         cur.bindValue(0, value);
         if (!cur.exec()) {
@@ -552,7 +552,7 @@ QSqlDatabase  svn::cache::LogCache::reposDb(const QString &aRepository)
  */
 QStringList svn::cache::LogCache::cachedRepositories()const
 {
-    static QString s_q(QString("select \"reposroot\" from ") + QString(SQLMAINTABLE) + QString(" order by reposroot"));
+    static const QString s_q(QLatin1String("select \"reposroot\" from ") + SQLMAINTABLE() + QLatin1String(" order by reposroot"));
     QSqlDatabase mainDB = m_CacheData->getMainDB();
     QStringList _res;
     if (!mainDB.isValid()) {
@@ -562,7 +562,7 @@ QStringList svn::cache::LogCache::cachedRepositories()const
     QSqlQuery cur(mainDB);
     cur.prepare(s_q);
     if (!cur.exec()) {
-        throw svn::cache::DatabaseException(QString("Could not retrieve values: ") + cur.lastError().text());
+        throw svn::cache::DatabaseException(QLatin1String("Could not retrieve values: ") + cur.lastError().text());
         return _res;
     }
     while (cur.next()) {
