@@ -31,8 +31,8 @@
 #include "svnqt/cache/DatabaseException.h"
 #include "svnqt/client_parameter.h"
 
-#include <qsqldatabase.h>
-
+#include <QDataStream>
+#include <QSqlDatabase>
 #include <QSqlError>
 #include <QSqlQuery>
 #include <QVariant>
@@ -122,7 +122,7 @@ svn::Revision svn::cache::ReposLog::latestCachedRev()
             return svn::Revision::UNDEFINED;
         }
     }
-    QString q("select revision from 'logentries' order by revision DESC limit 1");
+    static const QLatin1String q("select revision from 'logentries' order by revision DESC limit 1");
     QSqlQuery _q(QString(), m_Database);
     if (!_q.exec(q)) {
         //qDebug() << _q.lastError().text();
@@ -147,7 +147,7 @@ qlonglong svn::cache::ReposLog::count()const
             return svn::Revision::UNDEFINED;
         }
     }
-    QString q("select count(*) from 'logentries'");
+    static const QLatin1String q("select count(*) from 'logentries'");
     QSqlQuery _q(QString(), m_Database);
     if (!_q.exec(q)) {
         //qDebug() << _q.lastError().text();
@@ -192,7 +192,7 @@ qlonglong svn::cache::ReposLog::itemCount()const
             return -1;
         }
     }
-    QString q("select count(*) from 'changeditems'");
+    static const QLatin1String q("select count(*) from 'changeditems'");
     QSqlQuery _q(QString(), m_Database);
     if (!_q.exec(q)) {
         //qDebug() << _q.lastError().text();
@@ -273,7 +273,7 @@ bool svn::cache::ReposLog::checkFill(svn::Revision &start, svn::Revision &end, b
             if (cp && cp->getListener()) {
                 //cp->getListener()->contextProgress(++icount,_internal.size());
                 if (cp->getListener()->contextCancel()) {
-                    throw DatabaseException(QString("Could not retrieve values: User cancel."));
+                    throw DatabaseException(QStringLiteral("Could not retrieve values: User cancel."));
                 }
             }
         }
@@ -292,7 +292,7 @@ bool svn::cache::ReposLog::fillCache(const svn::Revision &_end)
 /*!
     \fn svn::cache::ReposLog::simpleLog(const svn::Revision&start,const svn::Revision&end,LogEntriesMap&target)
  */
-bool svn::cache::ReposLog::simpleLog(LogEntriesMap &target, const svn::Revision &_start, const svn::Revision &_end, bool noNetwork, const QStringList &exclude)
+bool svn::cache::ReposLog::simpleLog(LogEntriesMap &target, const svn::Revision &_start, const svn::Revision &_end, bool noNetwork, const StringArray &exclude)
 {
     if (!m_Client || m_ReposRoot.isEmpty()) {
         return false;
@@ -317,26 +317,14 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap &target, const svn::Revision
     if (start == svn::Revision::HEAD) {
         start = latestCachedRev();
     }
-    static QString sCount("select count(*) from logentries where revision<=? and revision>=?");
-    static QString sEntry("select revision,author,date,message from logentries where revision<=? and revision>=?");
-    static QString sItems("select changeditem,action,copyfrom,copyfromrev from changeditems where revision=?");
-
-    for (int i = 0; i < exclude.size(); ++i) {
-        sItems += " and changeditem not like '" + exclude[i] + "%'";
-    }
-
-    QSqlQuery bcount(QString(), m_Database);
-    bcount.prepare(sCount);
-
-    QSqlQuery bcur(QString(), m_Database);
-
-    QSqlQuery cur(QString(), m_Database);
 
+    QSqlQuery bcount(m_Database);
+    bcount.prepare(QStringLiteral("select count(*) from logentries where revision<=? and revision>=?"));
     bcount.bindValue(0, Q_LLONG(end.revnum()));
     bcount.bindValue(1, Q_LLONG(start.revnum()));
     if (!bcount.exec()) {
         //qDebug() << bcount.lastError().text();
-        throw svn::cache::DatabaseException(QString("Could not retrieve count: ") + bcount.lastError().text());
+        throw svn::cache::DatabaseException(QLatin1String("Could not retrieve count: ") + bcount.lastError().text());
         return false;
     }
     if (!bcount.next() || bcount.value(0).toLongLong() < 1) {
@@ -344,27 +332,35 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap &target, const svn::Revision
         return false;
     }
 
+    QSqlQuery bcur(m_Database);
     bcur.setForwardOnly(true);
-    bcur.prepare(sEntry);
+    bcur.prepare(QStringLiteral("select revision,author,date,message from logentries where revision<=? and revision>=?"));
     bcur.bindValue(0, Q_LLONG(end.revnum()));
     bcur.bindValue(1, Q_LLONG(start.revnum()));
 
     if (!bcur.exec()) {
-        throw svn::cache::DatabaseException(QString("Could not retrieve values: ") + bcur.lastError().text());
+        throw svn::cache::DatabaseException(QLatin1String("Could not retrieve values: ") + bcur.lastError().text());
         return false;
     }
-    Q_LLONG revision;
+
+    QString sItems(QStringLiteral("select changeditem,action,copyfrom,copyfromrev from changeditems where revision=?"));
+    for (int i = 0; i < exclude.size(); ++i) {
+        sItems += QLatin1String(" and changeditem not like '") + exclude[i] + QLatin1String("%'");
+    }
+    QSqlQuery cur(m_Database);
+    cur.setForwardOnly(true);
+    cur.prepare(sItems);
+
     while (bcur.next()) {
-        cur.setForwardOnly(true);
-        cur.prepare(sItems);
-        revision = bcur.value(0).toLongLong();
+        const Q_LLONG revision = bcur.value(0).toLongLong();
         cur.bindValue(0, revision);
 
         if (!cur.exec()) {
-            //qDebug() << cur.lastError().text();
-            throw svn::cache::DatabaseException(QString("Could not retrieve revision values: ") + cur.lastError().text()
-                                                , cur.lastError().number());
-            return false;
+          //qDebug() << cur.lastError().text();
+          throw svn::cache::DatabaseException(QStringLiteral("Could not retrieve revision values: %1, %2")
+                                              .arg(cur.lastError().text(),
+                                                   cur.lastError().nativeErrorCode()));
+          return false;
         }
         target[revision].revision = revision;
         target[revision].author = bcur.value(1).toString();
@@ -381,7 +377,7 @@ bool svn::cache::ReposLog::simpleLog(LogEntriesMap &target, const svn::Revision
         }
         if (cp && cp->getListener()) {
             if (cp->getListener()->contextCancel()) {
-                throw svn::cache::DatabaseException(QString("Could not retrieve values: User cancel."));
+                throw svn::cache::DatabaseException(QStringLiteral("Could not retrieve values: User cancel."));
                 return false;
             }
         }
@@ -400,8 +396,7 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision &aRev, bo
     if (!m_Database.isValid()) {
         return svn::Revision::UNDEFINED;
     }
-    static QString _q("select revision from logentries where date<? order by revision desc");
-    QSqlQuery query("select revision,date from logentries order by revision desc limit 1", m_Database);
+    QSqlQuery query(QStringLiteral("select revision,date from logentries order by revision desc limit 1"), m_Database);
 
     if (query.lastError().type() != QSqlError::NoError) {
         //qDebug() << query.lastError().text();
@@ -419,7 +414,7 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision &aRev, bo
         }
         return e[0].revision();
     }
-    query.prepare(_q);
+    query.prepare(QStringLiteral("select revision from logentries where date<? order by revision desc"));
     query.bindValue(0, Q_LLONG(aRev.date()));
     if (query.exec() && query.next()) {
         return query.value(0).toInt();
@@ -441,8 +436,8 @@ svn::Revision svn::cache::ReposLog::date2numberRev(const svn::Revision &aRev, bo
 bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry &aEntry)
 {
     qlonglong j = aEntry.revision;
-    static QString qEntry("insert into logentries (revision,date,author,message) values (?,?,?,?)");
-    static QString qPathes("insert into changeditems (revision,changeditem,action,copyfrom,copyfromrev) values (?,?,?,?,?)");
+    static const QLatin1String qEntry("insert into logentries (revision,date,author,message) values (?,?,?,?)");
+    static const QLatin1String qPathes("insert into changeditems (revision,changeditem,action,copyfrom,copyfromrev) values (?,?,?,?,?)");
     QSqlQuery _q(QString(), m_Database);
     _q.prepare(qEntry);
     _q.bindValue(0, j);
@@ -452,24 +447,24 @@ bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry &aEntry)
     if (!_q.exec()) {
         //qDebug("Could not insert values: %s",_q.lastError().text().toUtf8().data());
         //qDebug() << _q.lastQuery();
-        throw svn::cache::DatabaseException(QString("_insertLogEntry_0: Could not insert values: ") + _q.lastError().text(), _q.lastError().number());
+        throw svn::cache::DatabaseException(QStringLiteral("_insertLogEntry_0: Could not insert values: %1, %2").arg(_q.lastError().text(), _q.lastError().nativeErrorCode()));
     }
     _q.prepare(qPathes);
     svn::LogChangePathEntries::ConstIterator cpit = aEntry.changedPaths.begin();
     for (; cpit != aEntry.changedPaths.end(); ++cpit) {
         _q.bindValue(0, j);
         _q.bindValue(1, (*cpit).path);
-        _q.bindValue(2, QString(QChar((*cpit).action)));
+        _q.bindValue(2, QString(QLatin1Char((*cpit).action)));
         _q.bindValue(3, (*cpit).copyFromPath);
         _q.bindValue(4, Q_LLONG((*cpit).copyFromRevision));
         if (!_q.exec()) {
             //qDebug("Could not insert values: %s",_q.lastError().text().toUtf8().data());
             //qDebug() << _q.lastQuery();
-            throw svn::cache::DatabaseException(QString("Could not insert values: ") + _q.lastError().text(), _q.lastError().number());
+            throw svn::cache::DatabaseException(QStringLiteral("Could not insert values: %1, %2").arg(_q.lastError().text(), _q.lastError().nativeErrorCode()));
         }
     }
-    if (aEntry.m_MergedInRevisions.size() > 0) {
-        static QString qMerges("insert into mergeditems(revision,mergeditems) values(?,?)");
+    if (!aEntry.m_MergedInRevisions.isEmpty()) {
+        static const QLatin1String qMerges("insert into mergeditems(revision,mergeditems) values(?,?)");
         _q.prepare(qMerges);
         QByteArray _merges;
         QBuffer buffer(&_merges);
@@ -478,11 +473,11 @@ bool svn::cache::ReposLog::_insertLogEntry(const svn::LogEntry &aEntry)
         af << aEntry.m_MergedInRevisions;
         buffer.close();
         _q.bindValue(0, j);
-        _q.bindValue(1, _merges.data());
+        _q.bindValue(1, _merges);
         if (!_q.exec()) {
             //qDebug("Could not insert values: %s",_q.lastError().text().toUtf8().data());
             //qDebug() << _q.lastQuery();
-            throw svn::cache::DatabaseException(QString("Could not insert values: ") + _q.lastError().text(), _q.lastError().number());
+            throw svn::cache::DatabaseException(QStringLiteral("Could not insert values: %1, %2").arg(_q.lastError().text(), _q.lastError().nativeErrorCode()));
         }
     }
     return true;
@@ -504,21 +499,21 @@ bool svn::cache::ReposLog::insertLogEntry(const svn::LogEntry &aEntry)
 bool svn::cache::ReposLog::log(const svn::Path &what, const svn::Revision &_start, const svn::Revision &_end, const svn::Revision &_peg, svn::LogEntriesMap &target, bool strictNodeHistory, int limit)
 {
     Q_UNUSED(strictNodeHistory);
-    static QString s_q("select logentries.revision,logentries.author,logentries.date,logentries.message from logentries where logentries.revision in (select changeditems.revision from changeditems where (changeditems.changeditem='%1' or changeditems.changeditem GLOB '%2/*') %3 GROUP BY changeditems.revision) ORDER BY logentries.revision DESC");
+    static const QLatin1String s_q("select logentries.revision,logentries.author,logentries.date,logentries.message from logentries where logentries.revision in (select changeditems.revision from changeditems where (changeditems.changeditem='%1' or changeditems.changeditem GLOB '%2/*') %3 GROUP BY changeditems.revision) ORDER BY logentries.revision DESC");
 
-    static QString s_e("select changeditem,action,copyfrom,copyfromrev from changeditems where changeditems.revision='%1'");
-    static QString s_m("select mergeditems from mergeditems where mergeditems.revision='%1'");
+    static const QLatin1String s_e("select changeditem,action,copyfrom,copyfromrev from changeditems where changeditems.revision='%1'");
+    static const QLatin1String s_m("select mergeditems from mergeditems where mergeditems.revision='%1'");
 
     svn::Revision peg = date2numberRev(_peg, true);
-    QString query_string = QString(s_q).arg(what.native()).arg(what.native()).arg((peg == svn::Revision::UNDEFINED ? QString() : QString(" AND revision<=%1").arg(peg.revnum())));
+    QString query_string = QString(s_q).arg(what.native(), what.native(), (peg == svn::Revision::UNDEFINED ? QString() : QStringLiteral(" AND revision<=%1").arg(peg.revnum())));
     if (peg == svn::Revision::UNDEFINED) {
         peg = latestCachedRev();
     }
     if (!itemExists(peg, what)) {
-        throw svn::cache::DatabaseException(QString("Entry '%1' does not exists at revision %2").arg(what.native()).arg(peg.toString()));
+        throw svn::cache::DatabaseException(QStringLiteral("Entry '%1' does not exists at revision %2").arg(what.native(), peg.toString()));
     }
     if (limit > 0) {
-        query_string += QString(" LIMIT %1").arg(limit);
+        query_string += QStringLiteral(" LIMIT %1").arg(limit);
     }
     QSqlQuery _q(m_Database);
     QSqlQuery _q2(m_Database);
@@ -527,7 +522,7 @@ bool svn::cache::ReposLog::log(const svn::Path &what, const svn::Revision &_star
     if (!_q.exec()) {
         //qDebug("Could not select values: %s",_q.lastError().text().toUtf8().data());
         //qDebug() << _q.lastQuery();
-        throw svn::cache::DatabaseException(QString("Could not select values: ") + _q.lastError().text(), _q.lastError().number());
+        throw svn::cache::DatabaseException(QStringLiteral("Could not select values: %1, %2").arg(_q.lastError().text(), _q.lastError().nativeErrorCode()));
     }
     while (_q.next()) {
         Q_LLONG revision = _q.value(0).toLongLong();
@@ -535,7 +530,7 @@ bool svn::cache::ReposLog::log(const svn::Path &what, const svn::Revision &_star
         target[revision].author = _q.value(1).toString();
         target[revision].date = _q.value(2).toLongLong();
         target[revision].message = _q.value(3).toString();
-        query_string = s_e.arg(revision);
+        query_string = QString(s_e).arg(revision);
         _q2.setForwardOnly(true);
         _q2.prepare(query_string);
         if (!_q2.exec()) {
@@ -551,7 +546,7 @@ bool svn::cache::ReposLog::log(const svn::Path &what, const svn::Revision &_star
                 );
             }
         }
-        query_string = s_m.arg(revision);
+        query_string = QString(s_m).arg(revision);
         _q2.prepare(query_string);
         if (!_q2.exec()) {
             //qDebug("Could not select values: %s",_q2.lastError().text().toUtf8().data());
@@ -619,16 +614,16 @@ void svn::cache::ReposLog::cleanLogEntries()
     }
     DatabaseLocker l(&m_Database);
     QSqlQuery _q(QString(), m_Database);
-    if (!_q.exec("delete from logentries")) {
+    if (!_q.exec(QStringLiteral("delete from logentries"))) {
         return;
     }
-    if (!_q.exec("delete from changeditems")) {
+    if (!_q.exec(QStringLiteral("delete from changeditems"))) {
         return;
     }
-    if (!_q.exec("delete from mergeditems")) {
+    if (!_q.exec(QStringLiteral("delete from mergeditems"))) {
         return;
     }
 
     l.commit();
-    _q.exec("vacuum");
+    _q.exec(QStringLiteral("vacuum"));
 }
