@@ -28,36 +28,59 @@
  * history and logs, available at http://rapidsvn.tigris.org/.
  * ====================================================================
  */
-
+#if defined( _MSC_VER) && _MSC_VER <= 1200
+#pragma warning( disable: 4786 )// debug symbol truncated
+#endif
 // svncpp
-#include "client_impl.h"
+#include "svnqt/client_impl.h"
 
 // subversion api
-#include <svn_client.h>
+#include "svn_client.h"
 
-#include "exception.h"
-#include "pool.h"
-#include "targets.h"
-#include "svnqt_defines.h"
-#include "stringarray.h"
-#include "client_parameter.h"
-#include "client_commit_parameter.h"
-#include "client_update_parameter.h"
-#include "url.h"
-#include "helper.h"
+#include "svnqt/exception.h"
+#include "svnqt/pool.h"
+#include "svnqt/targets.h"
+#include "svnqt/svnqt_defines.h"
+#include "svnqt/stringarray.h"
+#include "svnqt/client_parameter.h"
+#include "svnqt/client_commit_parameter.h"
+#include "svnqt/client_update_parameter.h"
+#include "svnqt/url.h"
+
+#include "svnqt/helper.h"
+
+#include <QCoreApplication>
 
 namespace svn
 {
-static svn_error_t *
-svnqt_commit_callback2_func(
-    const svn_commit_info_t *commit_info,
-    void *baton,
-    apr_pool_t *)
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+struct mBaton {
+    mBaton(): m_context(), m_revision(Revision::UNDEFINED), m_date(), author(), commit_error(), repos_root() {}
+    ContextWP m_context;
+    svn::Revision m_revision;
+    QString m_date, author, commit_error, repos_root;
+};
+
+static svn_error_t *commit_callback2(const svn_commit_info_t *commit_info, void *baton, apr_pool_t *pool)
 {
-    svn_commit_info_t *ci = static_cast<svn_commit_info_t *>(baton);
-    *ci = *commit_info;
+    Q_UNUSED(pool);
+    mBaton *m_baton = (mBaton *)baton;
+    ContextP m_context = m_baton->m_context;
+    if (!m_context) {
+        return svn_error_create(SVN_ERR_CANCELLED, 0, QCoreApplication::translate("svnqt", "Cancelled by user.").toUtf8());
+    }
+    svn_client_ctx_t *ctx = m_context->ctx();
+    if (ctx && ctx->cancel_func) {
+        SVN_ERR(ctx->cancel_func(ctx->cancel_baton));
+    }
+    m_baton->author = QString::fromUtf8(commit_info->author);
+    m_baton->commit_error = QString::fromUtf8(commit_info->post_commit_err);
+    m_baton->m_date = QString::fromUtf8(commit_info->date);
+    m_baton->repos_root = QString::fromUtf8(commit_info->repos_root);
+    m_baton->m_revision = commit_info->revision;
     return SVN_NO_ERROR;
 }
+#endif
 
 Revision
 Client_impl::checkout(const CheckoutParameter &parameters) throw (ClientException)
@@ -65,7 +88,6 @@ Client_impl::checkout(const CheckoutParameter &parameters) throw (ClientExceptio
     Pool subPool;
     svn_revnum_t revnum = 0;
     svn_error_t *error = 0;
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     error = svn_client_checkout3(&revnum,
                                  parameters.moduleName().cstr(),
                                  parameters.destination().cstr(),
@@ -76,19 +98,6 @@ Client_impl::checkout(const CheckoutParameter &parameters) throw (ClientExceptio
                                  parameters.overWrite(),
                                  *m_context,
                                  subPool);
-#else
-    bool recurse = parameters.depth() == DepthInfinity;
-    Q_UNUSED(overwrite);
-    error = svn_client_checkout2(&revnum,
-                                 parameters.moduleName().cstr(),
-                                 parameters.destination().cstr(),
-                                 parameters.peg().revision(),
-                                 parameters.revision().revision(),
-                                 recurse,
-                                 parameters.ignoreExternals(),
-                                 *m_context,
-                                 subPool);
-#endif
     if (error != NULL) {
         throw ClientException(error);
     }
@@ -103,11 +112,24 @@ Client_impl::remove(const Targets &targets,
                    ) throw (ClientException)
 {
     Pool pool;
+    svn_error_t *error;
 
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
+    error = svn_client_delete4(
+                targets.array(pool),
+                force,
+                keep_local,
+                map2hash(revProps, pool),
+                commit_callback2,
+                &_baton,
+                *m_context,
+                pool
+            );
+#else
     svn_commit_info_t *commit_info = 0;
-
-    svn_error_t *error =
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+    error =
         svn_client_delete3(
             &commit_info,
             targets.array(pool),
@@ -117,23 +139,18 @@ Client_impl::remove(const Targets &targets,
             *m_context,
             pool
         );
-#else
-        svn_client_delete2
-        (&commit_info,
-         const_cast<apr_array_header_t *>(targets.array(pool)),
-         force,
-         *m_context,
-         pool);
-    Q_UNUSED(keep_local);
-    Q_UNUSED(revProps);
 #endif
     if (error != 0) {
         throw ClientException(error);
     }
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info) {
         return commit_info->revision;
     }
     return Revision::UNDEFINED;
+#endif
 }
 
 void
@@ -144,23 +161,12 @@ Client_impl::revert(const Targets &targets,
 {
     Pool pool;
 
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     svn_error_t *error =
         svn_client_revert2((targets.array(pool)),
                            internal::DepthToSvn(depth),
                            changelist.array(pool),
                            *m_context,
                            pool);
-
-#else
-    bool recurse = depth == DepthInfinity;
-    Q_UNUSED(changelist);
-    svn_error_t *error =
-        svn_client_revert((targets.array(pool)),
-                          recurse,
-                          *m_context,
-                          pool);
-#endif
     if (error != NULL) {
         throw ClientException(error);
     }
@@ -171,7 +177,7 @@ Client_impl::add(const Path &path,
                  svn::Depth depth, bool force, bool no_ignore, bool add_parents) throw (ClientException)
 {
     Pool pool;
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+    // todo svn 1.8: svn_client_add5
     svn_error_t *error =
         svn_client_add4(path.cstr(),
                         internal::DepthToSvn(depth),
@@ -180,16 +186,6 @@ Client_impl::add(const Path &path,
                         add_parents,
                         *m_context,
                         pool);
-#else
-    Q_UNUSED(add_parents);
-    svn_error_t *error =
-        svn_client_add3(path.cstr(),
-                        depth == DepthInfinity,
-                        force,
-                        no_ignore,
-                        *m_context,
-                        pool);
-#endif
     if (error != NULL) {
         throw ClientException(error);
     }
@@ -204,9 +200,9 @@ Client_impl::update(const UpdateParameter &params) throw (ClientException)
 
     apr_pool_t *apr_pool = pool.pool();
     apr_array_header_t *apr_revisions = apr_array_make(apr_pool,
-                                        params.targets().size(),
-                                        sizeof(svn_revnum_t));
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 7)) || (SVN_VER_MAJOR > 1)
+                                                       params.targets().size(),
+                                                       sizeof(svn_revnum_t));
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
     error = svn_client_update4(&apr_revisions, params.targets().array(pool), params.revision(),
                                internal::DepthToSvn(params.depth()), params.sticky_depth(),
                                params.ignore_externals(), params.allow_unversioned(),
@@ -233,17 +229,16 @@ Client_impl::commit(const CommitParameter &parameters) throw (ClientException)
 {
     Pool pool;
 
-    m_context->setLogMessage(parameters.message());
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
+#else
     svn_commit_info_t *commit_info = NULL;
-
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 7)) || (SVN_VER_MAJOR > 1)
-    svn_commit_info_t ci;
-    commit_info = &ci;
-    memset(commit_info, 0, sizeof(svn_commit_info_t));
-    commit_info->revision = SVN_INVALID_REVNUM;
-
+#endif
+    m_context->setLogMessage(parameters.message());
     svn_error_t *error =
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 8)) || (SVN_VER_MAJOR > 1)
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,8,0)
         svn_client_commit6(
 #else
         svn_client_commit5(
@@ -252,20 +247,19 @@ Client_impl::commit(const CommitParameter &parameters) throw (ClientException)
             internal::DepthToSvn(parameters.depth()),
             parameters.keepLocks(),
             parameters.keepChangeList(),
-            true, /* commit_as_operations */
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 8)) || (SVN_VER_MAJOR > 1)
+            parameters.commitAsOperations(),
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,8,0)
             false, /* file externals */
             false, /* dir externals */
 #endif
             parameters.changeList().array(pool),
             map2hash(parameters.revisionProperties(), pool),
-            &svnqt_commit_callback2_func,
-            commit_info,
+            commit_callback2,
+            &_baton,
             *m_context,
-            pool);
-#elif ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
-
-    svn_error_t *error =
+            pool
+        );
+#else
         svn_client_commit4(
             &commit_info,
             parameters.targets().array(pool),
@@ -276,26 +270,17 @@ Client_impl::commit(const CommitParameter &parameters) throw (ClientException)
             map2hash(parameters.revisionProperties(), pool),
             *m_context,
             pool);
-#else
-    bool recurse = parameters.depth() == DepthInfinity;
-
-    svn_error_t *error =
-        svn_client_commit3
-        (&commit_info,
-         parameters.targets().array(pool),
-         recurse,
-         parameters.keepLocks(),
-         *m_context,
-         pool);
 #endif
     if (error != NULL) {
         throw ClientException(error);
     }
-
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info && SVN_IS_VALID_REVNUM(commit_info->revision)) {
         return (commit_info->revision);
     }
-
+#endif
     return svn::Revision::UNDEFINED;
 }
 
@@ -305,26 +290,8 @@ Client_impl::copy(const CopyParameter &parameter)throw (ClientException)
     if (parameter.srcPath().size() < 1) {
         throw ClientException("Wrong size of sources.");
     }
-#if ((SVN_VER_MAJOR==1) && (SVN_VER_MINOR < 5) )
-    Revision rev;
-    if (parameter.srcPath().size() > 1 && !parameter.getAsChild()) {
-        throw ClientException("Multiple sources not allowed");
-    }
 
-    Path _dest;
-    QString base, dir;
-    for (size_t j = 0; j < parameter.srcPath().size(); ++j) {
-        _dest = parameter.destination();
-        if (parameter.asChild()) {
-            sparameter.srcPath()[j].split(dir, base);
-            _dest.addComponent(base);
-        }
-        rev  = copy(parameter.srcPath()[j], srcRevision, _dest);
-    }
-    return rev;
-#else
     Pool pool;
-    svn_commit_info_t *commit_info = 0L;
     apr_array_header_t *sources = apr_array_make(pool, parameter.srcPath().size(), sizeof(svn_client_copy_source_t *));
     // not using .array() 'cause some extra information is needed for copy
     for (size_t j = 0; j < parameter.srcPath().size(); ++j) {
@@ -334,7 +301,21 @@ Client_impl::copy(const CopyParameter &parameter)throw (ClientException)
         source->peg_revision = parameter.pegRevision().revision();
         APR_ARRAY_PUSH(sources, svn_client_copy_source_t *) = source;
     }
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 6)) || (SVN_VER_MAJOR > 1)
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
+
+    svn_error_t *error =
+        svn_client_copy6(
+            sources,
+            parameter.destination().cstr(),
+            parameter.asChild(), parameter.makeParent(), parameter.ignoreExternal(),
+            map2hash(parameter.properties(), pool),
+            commit_callback2, &_baton,
+            *m_context, pool);
+
+#elif SVN_API_VERSION >= SVN_VERSION_CHECK(1,6,0)
+    svn_commit_info_t *commit_info = 0L;
     svn_error_t *error =
         svn_client_copy5(&commit_info,
                          sources,
@@ -342,6 +323,7 @@ Client_impl::copy(const CopyParameter &parameter)throw (ClientException)
                          parameter.asChild(), parameter.makeParent(), parameter.ignoreExternal(),
                          map2hash(parameter.properties(), pool), *m_context, pool);
 #else
+    svn_commit_info_t *commit_info = 0L;
     svn_error_t *error =
         svn_client_copy4(&commit_info,
                          sources,
@@ -351,11 +333,14 @@ Client_impl::copy(const CopyParameter &parameter)throw (ClientException)
     if (error != 0) {
         throw ClientException(error);
     }
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info) {
         return commit_info->revision;
     }
-    return Revision::UNDEFINED;
 #endif
+    return Revision::UNDEFINED;
 }
 
 Revision
@@ -363,70 +348,55 @@ Client_impl::copy(const Path &srcPath,
                   const Revision &srcRevision,
                   const Path &destPath) throw (ClientException)
 {
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     return copy(CopyParameter(srcPath, destPath).srcRevision(srcRevision).asChild(true).makeParent(false));
-#else
-    Pool pool;
-    svn_commit_info_t *commit_info = NULL;
-    svn_error_t *error =
-        svn_client_copy2
-        (&commit_info,
-         srcPath.cstr(),
-         srcRevision.revision(),
-         destPath.cstr(),
-         *m_context,
-         pool);
-
-    if (error != 0) {
-        throw ClientException(error);
-    }
-    if (commit_info) {
-        return commit_info->revision;
-    }
-    return Revision::UNDEFINED;
-#endif
 }
 
 svn::Revision Client_impl::move(const CopyParameter &parameter) throw (ClientException)
 {
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     Pool pool;
+
+    // todo svn 1.8: svn_client_move7
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
+    svn_error_t *error = svn_client_move6(
+                             parameter.srcPath().array(pool),
+                             parameter.destination().cstr(),
+                             parameter.asChild(),
+                             parameter.makeParent(),
+                             map2hash(parameter.properties(), pool),
+                             commit_callback2,
+                             &_baton,
+                             *m_context,
+                             pool
+                         );
+
+#else
     svn_commit_info_t *commit_info = 0;
     svn_error_t *error = svn_client_move5(
                              &commit_info,
                              parameter.srcPath().array(pool),
                              parameter.destination().cstr(),
-                             parameter.force(),
+                             false, // is ignored since subversion 1.7 so we ignore it, too
                              parameter.asChild(),
                              parameter.makeParent(),
                              map2hash(parameter.properties(), pool),
                              *m_context,
                              pool
                          );
+#endif
     if (error != 0) {
         throw ClientException(error);
     }
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info) {
         return commit_info->revision;
     }
     return Revision::UNDEFINED;
-#else
-    Revision rev;
-    if (srcPaths.size() > 1 && !asChild) {
-        throw ClientException("Multiple sources not allowed");
-    }
-    QString base, dir;
-    Path _dest;
-    for (size_t j = 0; j < srcPaths.size(); ++j) {
-        _dest = destPath;
-        if (asChild) {
-            srcPaths[j].split(dir, base);
-            _dest.addComponent(base);
-        }
-        rev = move(srcPaths[j], _dest, force);
-    }
-    return rev;
 #endif
+
 }
 
 svn::Revision
@@ -439,36 +409,44 @@ Client_impl::mkdir(const Targets &targets,
     Pool pool;
     m_context->setLogMessage(msg);
 
-    svn_commit_info_t *commit_info = NULL;
+
 
     svn_error_t *error = 0;
-
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
+    error = svn_client_mkdir4
+            (
+                const_cast<apr_array_header_t *>(targets.array(pool)),
+                makeParent,
+                map2hash(revProps, pool),
+                commit_callback2, &_baton,
+                *m_context, pool
+            );
+#else
+    svn_commit_info_t *commit_info = NULL;
     error = svn_client_mkdir3
             (&commit_info,
              const_cast<apr_array_header_t *>(targets.array(pool)),
              makeParent,
              map2hash(revProps, pool),
              *m_context, pool);
-#else
-    Q_UNUSED(makeParent);
-    Q_UNUSED(revProps);
-    error = svn_client_mkdir2
-            (&commit_info,
-             const_cast<apr_array_header_t *>(targets.array(pool)),
-             *m_context, pool);
 #endif
-
     /* important! otherwise next op on repository uses that logmessage again! */
     m_context->setLogMessage(QString());
 
     if (error != NULL) {
         throw ClientException(error);
     }
+
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info) {
         return commit_info->revision;
     }
     return Revision::UNDEFINED;
+#endif
 }
 
 void
@@ -488,19 +466,9 @@ Client_impl::cleanup(const Path &path) throw (ClientException)
 void Client_impl::resolve(const Path &path, Depth depth, const ConflictResult &resolution) throw (ClientException)
 {
     Pool pool;
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     const svn_wc_conflict_result_t *aResult = resolution.result(pool);
     svn_error_t *error = svn_client_resolve(path.cstr(), internal::DepthToSvn(depth), aResult->choice, *m_context, pool);
 
-#else
-    Q_UNUSED(resolution);
-    bool recurse = depth == DepthInfinity;
-    svn_error_t *error =
-        svn_client_resolved(path.cstr(),
-                            recurse,
-                            *m_context,
-                            pool);
-#endif
     if (error != NULL) {
         throw ClientException(error);
     }
@@ -511,40 +479,34 @@ Client_impl::doExport(const CheckoutParameter &params) throw (ClientException)
 {
     Pool pool;
     svn_revnum_t revnum = 0;
+    QByteArray _neolBA;
     const char *_neol;
     if (params.nativeEol().isNull()) {
         _neol = (const char *)0;
     } else {
-        _neol = params.nativeEol().toUtf8();
+        _neolBA = params.nativeEol().toUtf8();
+        _neol = _neolBA.constData();
     }
-#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
     svn_error_t *error =
-        svn_client_export4(&revnum,
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+        svn_client_export5(
+#else
+        svn_client_export4(
+#endif
+                           &revnum,
                            params.moduleName().cstr(),
                            params.destination().cstr(),
                            params.peg().revision(),
                            params.revision().revision(),
                            params.overWrite(),
                            params.ignoreExternals(),
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+                           params.ignoreKeywords(),
+#endif
                            internal::DepthToSvn(params.depth()),
                            _neol,
                            *m_context,
                            pool);
-#else
-    bool recurse = params.depth() == svn::DepthInfinity;
-    svn_error_t *error =
-        svn_client_export3(&revnum,
-                           params.moduleName().cstr(),
-                           params.destination().cstr(),
-                           params.peg().revision(),
-                           params.revision().revision(),
-                           params.overWrite(),
-                           params.ignoreExternals(),
-                           recurse,
-                           _neol,
-                           *m_context,
-                           pool);
-#endif
     if (error != NULL) {
         throw ClientException(error);
     }
@@ -553,29 +515,37 @@ Client_impl::doExport(const CheckoutParameter &params) throw (ClientException)
 
 Revision
 Client_impl::doSwitch(
-    const Path &path, const Url &url,
+    const Path &path,
+    const Url &url,
     const Revision &revision,
     Depth depth,
     const Revision &peg,
     bool sticky_depth,
     bool ignore_externals,
-    bool allow_unversioned
+    bool allow_unversioned,
+    bool ignore_ancestry
 ) throw (ClientException)
 {
     Pool pool;
     svn_revnum_t revnum = 0;
-    svn_error_t *error = 0;
-
-    error = svn_client_switch2(
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    svn_error_t *error = svn_client_switch3(
+#else
+    Q_UNUSED(ignore_ancestry);
+    svn_error_t *error = svn_client_switch2(
+#endif
                 &revnum,
                 path.cstr(),
-                url,
+                url.cstr(),
                 peg.revision(),
                 revision.revision(),
                 internal::DepthToSvn(depth),
                 sticky_depth,
                 ignore_externals,
                 allow_unversioned,
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+                ignore_ancestry,
+#endif
                 *m_context,
                 pool
             );
@@ -587,7 +557,7 @@ Client_impl::doSwitch(
 
 Revision
 Client_impl::import(const Path &path,
-                    const Url &url,
+                    const Url &importRepository,
                     const QString &message,
                     svn::Depth depth,
                     bool no_ignore, bool no_unknown_nodetype,
@@ -595,42 +565,73 @@ Client_impl::import(const Path &path,
                    ) throw (ClientException)
 
 {
-    svn_commit_info_t *commit_info = NULL;
     Pool pool;
 
     m_context->setLogMessage(message);
+    // todo svn 1.8: svn_client_import5
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    mBaton _baton;
+    _baton.m_context = m_context;
     svn_error_t *error =
-        svn_client_import3(&commit_info, path.cstr(), url,
+        svn_client_import4(path.cstr(),
+                           importRepository.cstr(),
+                           internal::DepthToSvn(depth), no_ignore, no_unknown_nodetype,
+                           map2hash(revProps, pool),
+                           commit_callback2, &_baton,
+                           *m_context, pool);
+#else
+    svn_commit_info_t *commit_info = NULL;
+    svn_error_t *error =
+        svn_client_import3(&commit_info, path.cstr(), importRepository.cstr(),
                            internal::DepthToSvn(depth), no_ignore, no_unknown_nodetype,
                            map2hash(revProps, pool),
                            *m_context, pool);
+#endif
+
     /* important! otherwise next op on repository uses that logmessage again! */
     m_context->setLogMessage(QString());
 
     if (error != 0) {
         throw ClientException(error);
     }
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    return _baton.m_revision;
+#else
     if (commit_info) {
         return commit_info->revision;
     }
     return Revision::UNDEFINED;
+#endif
 }
 
 void
 Client_impl::relocate(const Path &path,
                       const Url &from_url,
                       const Url &to_url,
-                      bool recurse) throw (ClientException)
+                      bool recurse,
+                      bool ignore_externals) throw (ClientException)
 {
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+    Q_UNUSED(recurse);
+#endif
     Pool pool;
     svn_error_t *error =
+#if SVN_API_VERSION >= SVN_VERSION_CHECK(1,7,0)
+        svn_client_relocate2(path.cstr(),
+                             from_url.cstr(),
+                             to_url.cstr(),
+                             ignore_externals,
+                             *m_context,
+                             pool);
+
+#else
         svn_client_relocate(path.cstr(),
-                            from_url,
-                            to_url,
+                            from_url.cstr(),
+                            to_url.cstr(),
                             recurse,
                             *m_context,
                             pool);
-
+#endif
     if (error != NULL) {
         throw ClientException(error);
     }
